==> Cosmos7.645.tar.gz: Cosmos7.645/Particle/Event/Xsection/Test/cgetXsInterface2.f <==
!    this must be modified depending on the int. model 
!      this is for dpmjet3
!    SEE also CosmosDat/UserHook/GetXsecDPM/Fit/toSpAbySp.f90
!   for getting true dpmjet3 x-sections > 50 GeV
!   for pp, pip, Kp subroutine cSppdpm,Spipdpm,SKpdpm in 
!   Cosmos/Particle/Event/Xsection/cSxpdpm.f90 can be used.
#include "BlockData/cblkGene.h"
      subroutine cgetXsIni
#include "Zevhnp.h"
c  #include "Zmanagerp.h"
      SxAbySxpOpt = 0  ! same as 2:  QGS2 like
      
      TotXSopt =  2    ! For pp   1: PDG  3: Totem 
                       !  2: between 1 and 3                
                       !  3 gives highest for pp.
                       !  pbarp uses PDG so pbap < pp.
      end subroutine cgetXsIni

!          This is somewhat totology; dpm cannot
!       get x-section on fly.   
!   For original dpmjet3 xsection, 
      subroutine cgetXsInterface2(pj, tg, xs)
      implicit none
#include  "Zglobalc.h"
#include  "Zcode.h"
#include  "Ztrack.h"
#include  "Ztrackv.h"
!        
      record /ptcl/ pj    ! input projectile
      record /ptcl/ tg    ! input target
      real(8),intent(out):: xs(3) ! in mb . inela, total, ela

      real(8):: mfp

      real(8):: A, Z
      
!          upto next ------------, the stuf is not needed 
      TrackBefMove.p = pj
      if( tg.code == kgnuc ) then
         TargetMassN = tg.subcode
      else
         TargetMassN =  1.
      endif
      TargetAtomicN = tg.charge
!      call cmfpdpmjet3(xs, mfp)  ! this gives total Xs at E< 4.1 GeV!      call cmfpOther(xs, mfp)     ! only inelastic
!     ------------------------
      Z = tg.charge
      A = TargetMassN
      call cinelx(pj, A, Z, xs(1))
      if( pj.code == kgnuc  .and. tg.code ==kgnuc )  then 
             ! For heavy pj and heavy target, only inela
         xs(2:3) = 0.
      else
         call ctotx2(pj, A, Z, xs(2))
         xs(3)= xs(2)-xs(1)
      endif
      end      subroutine cgetXsInterface2

==> Cosmos8.041.tar.gz: Cosmos8.041/Particle/Event/Xsection/Test/cgetXsInterface2.f <==
!    this must be modified depending on the int. model 
!      this is for dpmjet3
!    SEE also CosmosDat/UserHook/GetXsecDPM/Fit/toSpAbySp.f90
!   for getting true dpmjet3 x-sections > 50 GeV
!   for pp, pip, Kp subroutine cSppdpm,Spipdpm,SKpdpm in 
!   Cosmos/Particle/Event/Xsection/cSxpdpm.f90 can be used.
#include "BlockData/cblkGene.h"
      subroutine cgetXsIni
#include "Zevhnp.h"
!  #include "Zmanagerp.h"
      SxAbySxpOpt = 0           ! same as 1:  QGS2 like
                !0: QGS2  1: QGS2,   2: DPM   3: EPOS  4: old  
      TotXSopt =  2    ! For pp   1: PDG  3: Totem 
                       !  2: between 1 and 3                
                       !  3 gives highest for pp.
!  pbarp uses PDG so pbap < pp.
      write(0,*)
     *     ' Sig xA/xp by 0 or 1-->qgs2,  2-->dpm, 3-->epos, 4--old'
      read(*,*)  SxAbySxpOpt
      write(0,*) ' Your input is', SxAbySxpOpt
      write(0,*)
     *     'For  pp use 1-->PDG 3-->Totem 2-->bwtween them 3--> highet'
      read(*,*)  TotXSopt
      write(0,*) 'Your input is ',   TotXSopt
      end subroutine cgetXsIni

!          This is somewhat totology; dpm cannot
!       get x-section on fly.   
!   For original dpmjet3 xsection, 
      subroutine cgetXsInterface2(pj, tg, xs)
      implicit none
#include  "Zglobalc.h"
#include  "Zcode.h"
#include  "Ztrack.h"
#include  "Ztrackv.h"
!        
      type(ptcl):: pj    ! input projectile
      type(ptcl):: tg    ! input target
      real(8),intent(out):: xs(3) ! in mb . inela, total, ela

      real(8):: mfp

      real(8):: A, Z
      
!          upto next ------------, the stuf is not needed 
      TrackBefMove%p = pj
      if( tg%code == kgnuc ) then
         TargetMassN = tg%subcode
      else
         TargetMassN =  1.
      endif
      TargetAtomicN = tg%charge
!      call cmfpdpmjet3(xs, mfp)  ! this gives total Xs at E< 4.1 GeV!      call cmfpOther(xs, mfp)     ! only inelastic
!     ------------------------
      Z = tg%charge
      A = TargetMassN
      call cinelx(pj, A, Z, xs(1))
      if( pj%code == kgnuc  .and. tg%code ==kgnuc )  then 
             ! For heavy pj and heavy target, only inela
         xs(2:3) = 0.
      elseif( pj%code /=  kphoton ) then
         call ctotx2(pj, A, Z, xs(2))
         xs(3)= xs(2)-xs(1)
      else
         xs(2:3)= 0.
      endif
      end      subroutine cgetXsInterface2
